@@ -8,6 +8,7 @@
 
 #include <KFormat>
 #include <KLocalizedString>
+#include <QRegExp>
 
 #include "ksystemlog_debug.h"
 
@@ -150,7 +151,7 @@ QString ParsingHelper::parseSize(const QString &stringSize)
 QString ParsingHelper::parseHttpResponse(const QString &response)
 {
     // Search the response string in the map
-    QMap<QString, QString>::Iterator it = mMapHTTPResponse.find(response);
+    QMap<QString, QString>::Iterator const it = mMapHTTPResponse.find(response);
     if (it != mMapHTTPResponse.end()) {
         return i18nc("HttpResponseNumber HttpResponseDescription", "%1 %2", response, *it);
     } else {
